@@ -83,10 +83,10 @@ class Makecmd(object):
             pass
 
         new_filename = FILE[0:FILE.index('.')]+"\n"
-        os.system(f"cp {FILE} {self.exec_directory}")
+        os.system(f"sudo cp {FILE} {self.exec_directory}")
         os.system(
-            f"mv {self.exec_directory}/{FILE} {self.exec_directory}/{new_filename}")
-        os.system(f"chmod +x {self.exec_directory}/{new_filename}")
+            f"sudo mv {self.exec_directory}/{FILE} {self.exec_directory}/{new_filename}")
+        os.system(f"sudo chmod +x {self.exec_directory}/{new_filename}")
         os.system(f"touch {self.filename_directory}/filenames.txt")
 
         with open(f"{self.filename_directory}/filenames.txt", "r") as file_storage_read:
